@@ -6,12 +6,10 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Client;
 {
-  $Riak::Client::VERSION = '1.94';
+  $Riak::Client::VERSION = '1.95';
 }
-## use critic
 
 use 5.010;
 use Riak::Client::PBC;
@@ -26,8 +24,6 @@ use Module::Runtime qw(use_module);
 require bytes;
 use Moo;
 
-use AnyEvent::Handle;
-
 use IO::Socket::INET;
 use IO::Socket::Timeout;
 
@@ -85,113 +81,10 @@ has no_delay           => ( is => 'ro',                 isa => Bool, default  =>
 
 has no_auto_connect => ( is => 'ro', isa => Bool,  default  => sub {0} );
 
+has _on_connect_cb => ( is => 'rw' );
 
-has anyevent_mode => ( is => 'ro', reader => 'ae', isa => Bool, default  => sub {0} );
-
-has _cv_connected => ( is => 'ro', lazy => 1, default => sub { AE::cv });
 has _requests_lock => ( is => 'rw', default => sub { undef });
 
-has _handle => ( is => 'ro', lazy => 1, builder => 1 );
-sub _build__handle {
-    my ($self) = @_;
-    my ($host, $port) = ($self->host, $self->port);
-
-    weaken $self;
-
-    # TODO = timeouts
-    AnyEvent::Handle->new (
-      connect  => [$host, $port],
-      no_delay => $self->no_delay(),
-      on_error => sub {
-        $_[0]->destroy; # explicitly destroy handle
-
-        _die_generic_error("on host $host:$port: $_[2]", $self->_current_request_ae_args->[0] // {});
-    },
-#      rtimeout => $self->read_timeout,
-#      wtimeout => $self->write_timeout,
-#      on_prepare => sub { $self->connection_timeout },
-      on_connect => sub { $self->_cv_connected->send },
-#      on_timeout => sub { print STDERR " ---- PLOP \n";},
-    );
-
-}
-
-
-# Why are we doing that ? It's because we want to avoid creating these closure
-# everytime we send or recerive data from the socket. So we build them here
-# once and for all. However the tricky part is that these callbacks need to
-# access $self and $args. So we make sure they can.
-has _current_request_ae_args => ( is => 'rw', default => sub { [] } );
-has _handle_reader_callback => ( is => 'ro', lazy => 1, builder => 1 );
-sub _build__handle_reader_callback {
-    my ($self) = @_;
-    weaken $self;
-
-    my $handle_reader_callback_weak;
-
-    my $inner_handle_reader_callback = sub {
-        my ( $response_code, $response_body ) = unpack( 'c a*', $_[1] );
-    
-        my $args = $self->_current_request_ae_args->[0]
-          or _die_generic_error( "Unexpected Response (got: $response_code, expected: nothing)", {} );
-
-
-        # in case of error msg
-        if ($response_code == ERROR_RESPONSE_CODE) {
-            my $decoded_message = RpbErrorResp->decode($response_body);
-            my $errmsg  = $decoded_message->errmsg;
-            my $errcode = $decoded_message->errcode;
-    
-            _die_generic_error( "Riak Error (code: $errcode) '$errmsg'", $args );
-        }
-    
-        # check if we have what we want
-        $response_code != $args->{expected_code}
-          and _die_generic_error(
-                                 "Unexpected Response Code in (got: $response_code, expected: $args->{expected_code})",
-                                 $args );
-    
-        # default value if we don't need to handle the response.
-        my ($ret, $more_to_come) = ( \1, undef);
-        # remember, $handle_response may or may not use $args->{cb}
-        if (my $handle_response = $args->{handle_response}) {
-            ($ret, $more_to_come) = $handle_response->( $self, $response_body, $args );
-        }
-        # if we expect more to come, re-prepend the handler
-        $more_to_come and $_[0]->unshift_read( chunk => 4, $handle_reader_callback_weak),
-          return;
-    
-        # ok, single or multiple response are over, remove the current request
-        # args, and remove the lock. This is done before last callback
-        # execution, so that user can re-enqueue a request right away.
-        shift @{$self->_current_request_ae_args};
-        my $lock = $self->_requests_lock;
-        $lock and $lock->send();
-    
-        # if no user callback provided, use the $cv and return.
-        !$args->{cb}
-          and $args->{cv}->send($ret),
-          return;
-    
-        # If $ret is undef, means everything has been processed and
-        # callback called in $handle_response, nothing left to do.
-        # Otherwise, we have a result, call the callback on it
-        $ret and $args->{cb}->($$ret);
-    
-    };
-
-    my $handle_reader_callback = sub {
-        # length arrived, decode
-        my $len = unpack "N", $_[1];
-        # now read the payload
-        $_[0]->unshift_read( chunk => $len, $inner_handle_reader_callback);
-    };
-
-    $handle_reader_callback_weak = $handle_reader_callback;
-    weaken $handle_reader_callback_weak;
-    $handle_reader_callback;
-}
-
 has _socket => ( is => 'ro', lazy => 1, builder => 1 );
 sub _build__socket {
     my ($self) = @_;
@@ -239,22 +132,12 @@ sub connect {
     state $check = compile(Any, Optional[CodeRef]);
     my ( $self, $cb ) = $check->(@_);
 
-    if ( ! $self->ae ) {
-        $self->_socket();
-        if ($cb) {
-            $cb->();
-        } else {
-            return 1;
-        }
+    # that will perform connection
+    $self->_socket();
+    if ($cb) {
+        $cb->();
+        return;
     } else {
-
-        $self->_handle();
-        if (my $cb = ref $_[-1] eq 'CODE' ? $_[-1] : undef) {
-            $self->_cv_connected->cb($cb);
-            return;
-        }
-
-        $self->_cv_connected->recv;
         return 1;
     }
 
@@ -327,6 +210,7 @@ sub put_raw {
                            Optional[ArrayRef[Dict[bucket => Str, key => Str, tag => Str]]], # links
                           );
     my ( $self, $bucket, $key, $value, $content_type, $indexes, $links ) = $check->(@_);
+
     $content_type ||= 'plain/text';
     $self->_store( $bucket, $key, $value, $content_type, $indexes, $links, $cb);
 }
@@ -446,6 +330,7 @@ sub _fetch {
         handle_response => \&_handle_get_response,
         test_exist => $test_exist,
         cb => $cb,
+        cb_args => 1,
     } );
 }
 
@@ -453,7 +338,7 @@ sub _handle_get_response {
     my ( $self, $encoded_message, $args ) = @_;
 
     defined $encoded_message
-      or _die_generic_error( "Undefined Message", 'get', $args );
+      or return _die_generic_error( "Undefined Message", 'get', $args );
 
     my $decoded_message = RpbGetResp->decode($encoded_message);
     my $content = $decoded_message->content;
@@ -707,9 +592,6 @@ sub _handle_map_reduce_response {
 sub _parse_response {
     my ( $self, $args ) = @_;
 
-    $self->ae
-      and goto &_parse_response_ae;
-
     my $socket = $self->_socket;
     _send_bytes($socket, $args->{request_code}, $args->{body_ref} // \'');
 
@@ -717,7 +599,7 @@ sub _parse_response {
         my $response;
         # get and check response
         my $raw_response_ref = _read_response($socket)
-          or _die_generic_error( $! || "Socket Closed", $args);
+          or return _die_generic_error( $! || "Socket Closed", $args);
 
         my ( $response_code, $response_body ) = unpack( 'c a*', $$raw_response_ref );
 
@@ -727,13 +609,13 @@ sub _parse_response {
             my $errmsg  = $decoded_message->errmsg;
             my $errcode = $decoded_message->errcode;
 
-            _die_generic_error( "Riak Error (code: $errcode) '$errmsg'", $args);
+            return _die_generic_error( "Riak Error (code: $errcode) '$errmsg'", $args);
         }
 
 
         # check if we have what we want
         $response_code != $args->{expected_code}
-          and _die_generic_error(
+          and return _die_generic_error(
               "Unexpected Response Code in (got: $response_code, expected: $args->{expected_code})",
               $args );
     
@@ -761,68 +643,6 @@ sub _parse_response {
     }
 }
 
-sub _parse_response_ae {
-    my ( $self, $args ) = @_;
-
-
-    # OK so Riak doesn't support pipelining. That means that you can't send a
-    # request before the previous one has returned. Especially true for
-    # multiple response requests, like get_keys. So we need a way to detect
-    # that a running request is occuring, and we can't push_read before the
-    # previous request is done.
-
-    # if there is a lock on the requests
-    if ($self->_requests_lock) {
-        # wait to acquire lock
-        $self->_requests_lock->recv();
-        # delete the lock
-        $self->_requests_lock(undef);
-    }
-
-    # if this request can have multiple responses, set the lock.
-    $args->{lock_requests}
-      and $self->_requests_lock(AE::cv);
-
-    my $body_ref     = $args->{body_ref} // \'';
-    
-    $self->_handle->push_write(pack('N',
-          bytes::length($$body_ref) + 1)
-        . pack('c', $args->{request_code}) . $$body_ref
-    );
-
-    # maybe we'll use a cv to force synchronous call
-    my $cv;
-    # if we don't have a user callback, we need to be synchronous, create the cv.
-    $args->{cb}
-      or $cv = AE::cv;
-
-    # Store the cv also in the args so that the callback can get access to it
-    $args->{cv} = $cv;
-
-    # Finally, store the given args to be reacheble from $self, so that
-    # _handle_reader_callback can get it. We push it in our stack, because we
-    # can stack up multiple requests, and get the response only after that.
-    # However we have the guarantee from AnyEvent and Riak that we will get the
-    # answers in order (for a given Riak connection, that is, for a given
-    # $self).
-    push @{$self->_current_request_ae_args()}, $args;
-
-    # OK, now try to read from the socket with the handler
-    $self->_handle->push_read( chunk => 4, $self->_handle_reader_callback);
-
-    # we were given a user callback, don't be synchronous, immediately return.
-    $args->{cb} and return;
-
-    # no user callback, let's be synchronous
-    my $res = $cv->recv();
-    $res and
-      return $$res;
-
-    # $res was undef, that's an error here
-    _die_generic_error( "internal error: response handler returns <undef>, but not in callback mode",
-                               $args );
-}
-
 sub _die_generic_error {
     my ( $error, $args ) = @_;
 
@@ -834,11 +654,15 @@ sub _die_generic_error {
       and $extra = "(bucket: $bucket, key: $key) ";
 
     my $msg = "Error in '$operation_name' $extra: $error";
-    if (my $cv = $args->{cv}) {
+    if ( my $cb = $args->{cb} ) {        
+        $cb->((undef) x ($args->{cb_nb_args} // 0), $msg);
+        return;
+    } elsif (my $cv = $args->{cv}) {
         $cv->croak($msg);
     } else {
         croak $msg;
     }
+    return;
 }
 
 sub _read_response {
@@ -915,7 +739,7 @@ Riak::Client - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 1.94
+version 1.95
 
 =head1 SYNOPSIS
 
@@ -934,13 +758,6 @@ version 1.94
     no_auto_connect => 0,
   );
 
-  # AnyEvent mode
-  my $client = Riak::Client->new(
-    host => '127.0.0.1',
-    port => 8087
-    anyevent_mode => 1,
-  );
-
   $client->is_alive() or die "riak is not alive";
 
   # store hashref. will be serialized as JSON
@@ -961,16 +778,6 @@ version 1.94
   # delete data
   $client->del( 'bucket_name', 'key_name');
 
-  # AnyEvent mode
-  my $cv = AE::cv
-  $client->get_raw( 'bucket_name', 'key_name'
-                    sub { do_something_with($_[0]);
-                          $cv->send();
-                    }
-              );
-  # ... later one
-  $cv->recv();
-
   # list keys in stream
   $client->get_keys(foo => sub{
      my ($key, $done) = @_;
@@ -982,24 +789,16 @@ version 1.94
 
 =head1 DESCRIPTION
 
-Riak::Client is a fast and light Perl client for Riak using PBC interface, with
-optional AnyEvent mode.
+Riak::Client is a fast and light Perl client for Riak using PBC interface
 
 It supports operations like ping, get, exists, put, del, secondary indexes
 (so-called 2i) setting and querying, and Map Reduce querying.
 
-It has two modes, a traditional procedural mode, and an event based mode, using
-AnyEvent.
-
 It started as a fork of C<Riak::Light> to fix some bugs, but actually ended up
 in a complete rewrite with more features, but the same performance.
 
 =head1 ATTRIBUTES
 
-=head2 anyevent_mode
-
-Enables the AnyEvent mode, allowing true asynchronous mode.
-
 =head2 host
 
 Str, Required. Riak IP or hostname.
@@ -1039,14 +838,6 @@ you're doing.
 Bool, Default 0. If set to true, then the module won't automatically connect upon instanciation.
 Instead, you'll have to call C<connect()> yourself.
 
-=head2 anyevent_mode
-
-Bool, Default 0. If set to true, then all methods can receive a callback,
-as last argument. If present, the method will return immediately, and the
-callback will be executed upon completion of the operation, receiving a condvar
-as first and only argument. If set to false (the default), then the client
-instance will be synchronous.
-
 =head1 METHODS
 
 =head2 connect
@@ -1059,25 +850,13 @@ automatically done when C<new()> is called, unless the C<no_auto_connect>
 attribute is set to true. Accepts an optional callback, that will be executed
 when connected.
 
-  # example in AnyEvent mode
-  $cv = AE::cv;
-  $client->connect(sub { print "connected!\n"; $cv->send(); });
-  # ...
-  $cv->recv();
-
-=head2 ping
+=head2 ping( [$cb->()] )
 
  my $result = $client->ping();
- $client->ping($coderef);
+ $client->ping(sub { print "ping successful\n" });
 
 Performs a ping operation. On error, will raise an exception. Accepts an
-optional callback, that will be executed upon completion
-
-  # example in AnyEvent mode
-  $cv = AE::cv;
-  $client->ping(sub { print "got $_[0] \n"; $cv->send(); });
-  # ...
-  $cv->recv();
+optional callback (a CodeRef), that will be executed upon completion. 
 
   # an other example
   use Try::Tiny;
@@ -1085,39 +864,27 @@ optional callback, that will be executed upon completion
 
 See also C<is_alive()>.
 
-=head2 is_alive
+=head2 is_alive( [$cb->($bool)] )
 
  my $is_alive = $client->is_alive();
  $client->is_alive($coderef);
 
 Checks if the connection is alive. Returns true or false. On error, will raise
 an exception. Accepts an optional callback, that will be executed upon
-completion. Even in AnyEvent mode, this operation is synchronous.
+completion.
 
-  # example in AnyEvent mode
-  $cv = AE::cv;
-  $client->is_alive(sub { print($_[0] ? "alive\n" : "dead\n"); $cv->send(); });
-  # ...
-  $cv->recv();
-
-=head2 get
+=head2 get( $bucket, $key, [$cb->($value)] )
 
   my $value = $client->get($bucket, $key);
   $client->get($bucket, $key, $coderef);
 
-  # example in AnyEvent mode
-  $cv = AE::cv;
-  $client->get('bucket', 'key', sub { do_stuff_with_value($_[0]); $cv->send() });
-  # ...
-  $cv->recv();
-
 Performs a fetch operation. Expects bucket and key names. Returns the value. On
 error, will raise an exception. Accepts an optional callback, that will be
 called upon completion, with the value as first argument. If the content_type
 of the fetched value is C<'application/json'>, automatically decodes the JSON
 into a Perl structure. If you need the raw data you can use C<get_raw>.
 
-=head2 get_raw
+=head2 get_raw( $bucket, $key, [$cb->($value)] )
 
   my $value = $client->get_raw($bucket, $key);
   $client->get_raw($bucket, $key, $coderef);
@@ -1125,7 +892,7 @@ into a Perl structure. If you need the raw data you can use C<get_raw>.
 Same as C<get>, but no automatic JSON decoding will be performed. If you want
 JSON to be automatically decoded, you should use C<get()> instead.
 
-=head2 put
+=head2 put( $bucket, $key, $value, [ $mime_type, $secondary_indexes, $links ], [ $cb->($value) ] )
 
   $client->put($bucket, $key, $value);
   $client->put($bucket, $key, $value, $coderef);
@@ -1148,7 +915,7 @@ C<_bin>, depending if the index type is integer or binary.
 To query secondary indexes, see C<query_index>.
 
   $client->put('bucket', 'key', { some_values => [1,2,3] });
-  $client->put('bucket', 'key', { some_values => [1,2,3] }, 'application/json);
+  $client->put('bucket', 'key', { some_values => [1,2,3] }, 'application/json');
   $client->put('bucket', 'key', 'text', 'plain/text');
 
   # you can set secondary indexes (2i)
@@ -1180,17 +947,7 @@ To query secondary indexes, see C<query_index>.
                 ],
               );
 
-  # example in AnyEvent mode
-  $cv = AE::cv;
-  $client->put( 'bucket', 'key', 'some_text', 'plain/text',
-                { field1_bin => 'abc', field2_int => 42 },
-                { next_key => 'bucket2/foo'},
-                sub { print "data is sent to Riak\n"; $cv->send() },
-              );
-  # ...
-  $cv->recv();
-
-=head2 put_raw
+=head2 put_raw ( $bucket, $key, $value, [ $mime_type, $secondary_indexes, $links ], [ $cb->($value) ] )
 
   $client->put_raw('bucket', 'key', encode_json({ some_values => [1,2,3] }), 'application/json');
   $client->put_raw('bucket', 'key', 'text');
@@ -1212,13 +969,13 @@ C<_bin>, depending if the index type is integer or binary.
 
 To query secondary indexes, see C<query_index>.
 
-=head2 del
+=head2 del ( $bucket, $key, [ $cb->() ] )
 
   $client->del(bucket => key);
 
 Perform a delete operation. Expects bucket and key names.
 
-=head2 get_keys
+=head2 get_keys( $bucket, $cb->($key, $bool) )
 
   # in default mode
   $client->get_keys(foo => sub{
@@ -1227,15 +984,6 @@ Perform a delete operation. Expects bucket and key names.
      $another_client->del(foo => $key);
   });
 
-  # in anyevent mode
-  my $cv = AE::cv;
-  $client->get_keys(foo => sub{
-     my ($key, $done) = @_;
-     # ... do stuff with $key
-     $done and $cv->send;
-  });
-  $cv->recv();
-
 B<WARNING>, this method should not be called on a production Riak cluster, as
 it can have a big performance impact. See Riak's documentation.
 
@@ -1244,25 +992,25 @@ C<Riak::Client> instance inside the callback, it would raise an exception.
 
 Perform a list keys operation. Receive a callback and will call it for each
 key. The callback will receive two arguments: the key, and a boolean indicating
-if it's the last key
+if it's the last key.
 
-The callback is optional, in which case an ArrayRef of B<all> the keys are
-returned. But don't do that, and always provide a callback, to avoid your RAM
-usage to skyrocket...
+The callback is optional. If not provided C<get_keys()> will return an ArrayRef
+of B<all> the keys. Don't do that, and always provide a callback, to avoid your
+RAM usage to skyrocket...
 
-=head2 exists
+=head2 exists($bucket, $key, [ $cb->($bool) ] )
 
   $client->exists(bucket => 'key') or warn "key not found";
 
 Perform a fetch operation but with head => 0, and the if there is something
 stored in the bucket/key.
 
-=head2 query_index
+=head2 query_index( $bucket, $index, $value, [ $cb->($key) ] )
 
 Perform a secondary index (2i) query. Expects a bucket name, the index field
 name, the index value you're searching on, and optionally a callback.
 
-If a callback has been provided, doesn't return anything, but execute the
+If a callback has been provided, doesn't return anything, but executes the
 callback on each matching keys. callback will receive the key name as first
 argument. key name will also be in C<$_>. If no callback is provided, returns
 and ArrayRef of matching keys.
@@ -1283,50 +1031,74 @@ Based on the example in C<put>, here is how to query it:
   # range match with callback
   $client->query_index( 'bucket',  'field2_int', [ 40, 50], sub { print "key : $_" } ),
 
-=head2 get_buckets
+=head2 get_buckets( [ $cb->($buckets) ] )
 
 B<WARNING>, this method should not be called on a production Riak cluster, as
 it can have a big performance impact. See Riak's documentation.
 
-=head2 get_bucket_props
+=head2 get_bucket_props($bucket, [ $cb->($properties) ] )
 
-=head2 set_bucket_props
+=head2 set_bucket_props($bucket, $properties)
 
 =head2 map_reduce
 
+Perform a map/reduce operation.
+
+  # using a javascript function
+  my $json_hash = {
+      inputs => 'training',
+      query => [{
+        map => {
+          language =>"javascript",
+          source =>"function(riakObject) {
+            var val = riakObject.values[0].data.match(/pizza/g);
+            return [[riakObject.key, (val ? val.length : 0 )]];
+          }"
+        }
+      }]
+  };
+
+  # using an erlang function
+  my $json_hash = {
+      inputs => 'messages',
+      query => [{
+        map => {
+          language => 'erlang',
+          module => 'mr_example',
+          function => 'get_keys'
+        }
+      }]
+  };
+
+  $client->map_reduce($json_hash, sub { ... });
+
 =head2 map_reduce_raw
 
 =head1 BENCHMARKS
 
 Note: These benchmarks are the one provided by C<Riak::Light>.
 
-Note: the AnyEvent mode is a bit slower below, because we are forcing
-synchronous mode, even in AnyEvent, so the benchmark is paying the price of
-having AnyEvent enabled but not used.
-
 =head2 GETS
 
-                                  Rate Data::Riak (REST) Riak::Tiny (REST) Net::Riak (REST) Data::Riak::Fast (REST) Net::Riak (PBC) Riak::Client (PBC + AnyEvent) Riak::Light (PBC) Riak::Client (PBC)
-  Data::Riak (REST)              427/s                --              -30%             -31%                    -43%            -65%                          -85%              -90%               -91%
-  Riak::Tiny (REST)              611/s               43%                --              -2%                    -19%            -51%                          -79%              -86%               -87%
-  Net::Riak (REST)               623/s               46%                2%               --                    -17%            -50%                          -78%              -86%               -87%
-  Data::Riak::Fast (REST)        755/s               77%               24%              21%                      --            -39%                          -74%              -83%               -84%
-  Net::Riak (PBC)               1238/s              190%              103%              99%                     64%              --                          -57%              -72%               -74%
-  Riak::Client (PBC + AnyEvent) 2878/s              573%              371%             362%                    281%            132%                            --              -34%               -39%
-  Riak::Light (PBC)             4348/s              917%              612%             598%                    476%            251%                           51%                --                -8%
-  Riak::Client (PBC)            4706/s             1001%              671%             655%                    524%            280%                           64%                8%                 --
+                                  Rate Data::Riak (REST) Riak::Tiny (REST) Net::Riak (REST) Data::Riak::Fast (REST) Net::Riak (PBC) Riak::Client Riak::Light (PBC) Riak::Client (PBC)
+  Data::Riak (REST)              427/s                --              -30%             -31%                    -43%            -65%                           -90%               -91%
+  Riak::Tiny (REST)              611/s               43%                --              -2%                    -19%            -51%                           -86%               -87%
+  Net::Riak (REST)               623/s               46%                2%               --                    -17%            -50%                           -86%               -87%
+  Data::Riak::Fast (REST)        755/s               77%               24%              21%                      --            -39%                           -83%               -84%
+  Net::Riak (PBC)               1238/s              190%              103%              99%                     64%              --                           -72%               -74%
+  Riak::Light (PBC)             4348/s              917%              612%             598%                    476%            251%                             --                -8%
+  Riak::Client (PBC)            4706/s             1001%              671%             655%                    524%            280%                             8%                 --
 
 =head2 PUTS
 
-                                  Rate Net::Riak (REST) Data::Riak (REST) Riak::Tiny (REST) Data::Riak::Fast (REST) Net::Riak (PBC) Riak::Light (PBC) Riak::Client (PBC + AnyEvent) Riak::Client (PBC)
-  Net::Riak (REST)               542/s               --              -15%              -29%                    -55%            -57%              -90%                          -92%               -92%
-  Data::Riak (REST)              635/s              17%                --              -17%                    -47%            -49%              -89%                          -90%               -90%
-  Riak::Tiny (REST)              765/s              41%               20%                --                    -36%            -39%              -86%                          -88%               -88%
-  Data::Riak::Fast (REST)       1198/s             121%               89%               57%                      --             -4%              -79%                          -82%               -82%
-  Net::Riak (PBC)               1254/s             131%               97%               64%                      5%              --              -78%                          -81%               -81%
-  Riak::Light (PBC)             5634/s             939%              787%              637%                    370%            349%                --                          -14%               -14%
-  Riak::Client (PBC + AnyEvent) 6557/s            1110%              933%              757%                    448%            423%               16%                            --                 0%
-  Riak::Client (PBC)            6557/s            1110%              933%              757%                    448%            423%               16%                            0%                 --
+                                  Rate Net::Riak (REST) Data::Riak (REST) Riak::Tiny (REST) Data::Riak::Fast (REST) Net::Riak (PBC) Riak::Light (PBC) Riak::Client (PBC)
+  Net::Riak (REST)               542/s               --              -15%              -29%                    -55%            -57%              -90%               -92%
+  Data::Riak (REST)              635/s              17%                --              -17%                    -47%            -49%              -89%               -90%
+  Riak::Tiny (REST)              765/s              41%               20%                --                    -36%            -39%              -86%               -88%
+  Data::Riak::Fast (REST)       1198/s             121%               89%               57%                      --             -4%              -79%               -82%
+  Net::Riak (PBC)               1254/s             131%               97%               64%                      5%              --              -78%               -81%
+  Riak::Light (PBC)             5634/s             939%              787%              637%                    370%            349%                --               -14%
+  Riak::Client (PBC)            6557/s            1110%              933%              757%                    448%            423%               16%                 --
 
 =for Pod::Coverage BUILD
 
@@ -1342,8 +1114,6 @@ L<Action::Retry>
 
 L<Riak::Light>
 
-L<AnyEvent>
-
 =head1 CONTRIBUTORS
 
 Ivan Kruglov <ivan.kruglov@yahoo.com>
